#
# spec file for package frizbee
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           frizbee
Version:        0.1.2
Release:        1.2
Summary:        Throw a tag at and it comes back with a checksum
License:        Apache-2.0
URL:            https://github.com/stacklok/frizbee
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Frizbee is a tool you may throw a tag at and it comes back with a checksum.

It's a command-line tool designed to provide checksums for GitHub Actions and
container images based on tags.

It also includes a set of libraries for working with tags and checksums.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

# output of 'frizbee version' still partially broken/missing
# https://github.com/stacklok/frizbee/issues/148
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -tags=netgo \
   -ldflags=" \
   -X main.Version=%{version} \
   -X main.Commit=${COMMIT_HASH} \
   -X main.CommitDate=${BUILD_DATE} \
   -X main.TreeState=clean \
   -X github.com/stacklok/frizbee/internal/cli.CLIVersion=%{version}" \
   -o bin/%{name} main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.2:
  * Add cert string to goreleaser configuration (#198)
  * Bump anchore/sbom-action from 0.17.1 to 0.17.2 (#197)
  * Output certificate as part of frizbee release
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.1:
  * Bump github.com/moby/buildkit from 0.15.1 to 0.15.2
  * Bump anchore/sbom-action from 0.17.0 to 0.17.1
  * Bump sigstore/cosign-installer from 3.5.0 to 3.6.0
  * Bump actions/upload-artifact from 4.3.5 to 4.3.6
  * Bump github.com/google/go-containerregistry from 0.20.1 to
    0.20.2
  * Bump golang.org/x/sync from 0.7.0 to 0.8.0
  * Bump actions/upload-artifact from 4.3.4 to 4.3.5
  * Bump github.com/moby/buildkit from 0.15.0 to 0.15.1
  * Bump golangci/golangci-lint-action from 6.0.1 to 6.1.0
  * Use unmaintained version tag in tests
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.1.0:
  * Fix the default configuration note in README
  * Only ignore main and master, not all branches when pinning
    actions
  * Bump github.com/google/go-containerregistry from 0.20.0 to
    0.20.1
  * Bump slsa-framework/slsa-verifier from 2.5.1 to 2.6.0
  * Bump anchore/sbom-action from 0.16.1 to 0.17.0
  * chore: improve release binary
  * docs: update to use core tap
  * Bump github.com/moby/buildkit from 0.14.1 to 0.15.0 (#174)
  * Bump actions/setup-go from 5.0.1 to 5.0.2
  * Bump aquasecurity/trivy-action from 0.23.0 to 0.24.0
  * Bump anchore/sbom-action from 0.16.0 to 0.16.1
  * Bump github.com/google/go-containerregistry from 0.19.2 to
    0.20.0 (#170)
  * Bump actions/upload-artifact from 4.3.3 to 4.3.4
  * Bump actions/download-artifact from 4.1.7 to 4.1.8
  * Update Contributing & Community section in README.md
  * Update Contributor License Agreement link in CONTRIBUTING.md
  * Bump buf hashes again
  * Add readme entry pointing to the github action
  * Bump github.com/moby/buildkit from 0.14.0 to 0.14.1
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.0.20:
  * Always ignore scratch even with an empty config
  * Bump aquasecurity/trivy-action from 0.22.0 to 0.23.0
  * Make DefaultConfig public
  * Update documentation
  * Default to skipping actions referenced by a tag
  * Handle images with AS and platform, use excludes
  * Add a configuration to exclude images
  * Fix unit test hash reference and bump cobra and
    go-containerregistry
  * Bump actions/checkout from 4.1.6 to 4.1.7
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.0.19 (no releases between 0.0.16 and this
  one):
  * Fix missing ldflags while releasing
  * Rename folder to directory field
  * Update goreleaser config to v2
  * Update releaser.yml to use v2
  * Fix version variable path in goreleaser config
  * Bump aquasecurity/trivy-action from 0.21.0 to 0.22.0
  * Bump goreleaser/goreleaser-action from 5.1.0 to 6.0.0
* Mon Jun 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package frizbee: tool to replace image tags with shasums in
  e.g. Dockerfiles
